% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
%                4.3.2011      T. Roeder, Rohde&Schwarz
%
% *************************************************************************

session = 0;

% we run the following commands in a dummy loop that allows for
% an easier error handling
while( true )

    % locate and load the VXI-PnP driver DLL
    [Status, libname] = rs_nrpz_load_vxipnp();
    if( Status==0 ); break; end;

    % open any available sensor
    %   Set the resource descriptor for the USB Power Sensor  
    %   '*' uses the first available sensor. It is also possible
    %   to provide the USB resources string here, using the format
    %   'USB::<vendorID>::<productID>::<serial number>'
    %   The vendor ID for R&S instruments is 0x0AAD
    %   The product ID depends on the sensor. See the driver documentation
    %   or Power Viewer Plus manual for details.
    [Status, session] = rs_nrpz_init( libname, '*' );
    if( Status==0 ); break; end;
    
    % Read sensor name, e.g. 'NRP-Z81'
    [Status, Name] = rs_nrpz_get_sensorname( libname, session );
    if( Status==0 ); break; end;
    disp( [ 'Sensor Type: ' Name ] );
    
    disp ('  ');
    disp ('=== MEASURE POWER USING NRP-Z SENSOR ===');

    % Configure sensor for measurement
    frequency   = 1e9;
    leveloffset = 0.0;
    avcount     = 32;
    Status = rs_nrpz_setup_contav( libname, session, frequency,...
                                          leveloffset, avcount );
    if( Status==0 );  break;  end;
    
    % Run a few measurements and print the value.
    for i = 1:5
        
        [Status, Result] = rs_nrpz_read_measurement( libname, session );
        if( Status==0 );  break;  end;

        % Convert the linear reading from W into dBm
        if( Result>0 )               
            LogResultStr = num2str( 30 + 10 * log10( abs( Result ) ) );
        else
            LogResultStr = '---';
        end
        disp( ['Pav = ' num2str(Result) ' W   (' LogResultStr ' dBm)' ]);
    
    end
    
    break;
   
end

% Close sensor connection. It must be ensured that the sensor is closed
% at the end of the program !
%   It is possible to close rsnrpz_close() with 0 as the session number in
%   order to close all open sessions.
%   err = calllib( libname, 'rsnrpz_close', 0 );
rs_nrpz_close( libname, session ); 

% **********************************************************************
% Unloading the library may cause problems ('unhandled exceptions in
% MATLAB.exe'). It is therefore suggested to leave this library loaded.
% Restarting the script detects the libray and it is not loaded again.
% unloadlibrary( 'rsnrpz_32' ) or unloadlibrary( 'rsnrpz_64' )

clear;
disp (' ');
return;



