% function rs_nrpz_setup_contav 
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function sets up a Continuous Average Power measurement.
% @param  libname                     The name of the library.
% @param  session                     The session ID.
% @param  frequency                   The RF frequency in Hz.
% @param  leveloffset                 The level offset.
% @param  avcount                     The averaging filter count.
%%
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status] = rs_nrpz_setup_contav( libname, session, frequency,...
                                          leveloffset, avcount )  

    Status = 0;

    % we run the following commands in a dummy loop that allows for
    % an easier error handling
    while( true )

        % The sensor opened through rsnrpz_init() always uses channel 1.
        channel = 1;

        % Configure the sensor for the continuous power measurement.
        % 0 = RSNRPZ_SENSOR_MODE_CONTAV
        err = calllib( libname, 'rsnrpz_chan_mode', session, channel, 0 );
        if( err<0 );  break;  end;

        % Set the carrier frequency.
        err = calllib( libname, 'rsnrpz_chan_setCorrectionFrequency', session, channel, frequency );
        if( err<0 );  break;  end;

        % Set an optional level offset that accounts for losses or coupling
        % factors.
        err = calllib( libname, 'rsnrpz_corr_setOffset', session, channel, leveloffset );
        if( err<0 );  break;  end;

        % Enable or disable using the level offset.
        % 0 = disable
        err = calllib( libname, 'rsnrpz_corr_setOffsetEnabled', session, channel, 1 );
        if( err<0 );  break;  end;

        % Set the aperture (sampling window) to 10 ms.
        % Please see the sensor manual for details and valid ranges.
        % err = calllib( libname, 'rsnrpz_chan_setContAvAperture', session, channel, 10e-3 );
        % if( err<0 );  break;  end;

        % Turn smoothing (video low pass filter) off.
        % 0 = OFF
        err = calllib( libname, 'rsnrpz_chan_setContAvSmoothingEnabled', session, channel, 0 );
        if( err<0 );  break;  end;

        % Configure the sensor for an averaging filter using a count of 32.
        err = calllib( libname, 'rsnrpz_avg_configureAvgManual', session, channel, avcount );
        if( err<0 );  break;  end;

        % Set to repeating filter mode.
        % 1 = RSNRPZ_TERMINAL_CONTROL_REPEAT
        err = calllib( libname, 'rsnrpz_avg_setTerminalControl', session, channel, 1 );
        if( err<0 );  break;  end;

        break;

    end

    % evaluate error
    if( err<0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;

return;



